pyxmpp.jabber.muccore.HistoryParameters

Package pyxmpp :: Package jabber :: Module muccore :: Class HistoryParameters |
[hide private]

# Class HistoryParameters

source code

    object --+
             |
            HistoryParameters

Provides parameters for MUC history management

Instance Methods | [hide private]
__init__(self, maxchars=None, maxstanzas=None, maxseconds=None, since=None) Initializes a HistoryParameters object. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
`int` | maxchars limit of the total number of characters in history.
`int` | maxstanzas limit of the total number of messages in history.
`int` | seconds send only messages received in the last seconds seconds.
`datetime.datetime` | since Send only the messages received since the dateTime (UTC) specified.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, maxchars=None, maxstanzas=None, maxseconds=None, since=None) (Constructor) | source code
Initializes a HistoryParameters object. Parameters: `maxchars` (`int`) - limit of the total number of characters in history. `maxstanzas` (`int`) - limit of the total number of messages in history. `maxseconds` (`int`) - send only messages received in the last seconds seconds. `since` (`datetime.datetime`) - Send only the messages received since the dateTime specified. Overrides: object.__init__